#
# spec file for package awesome-vicious
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packname   vicious

Name:           awesome-vicious
Version:        2.5.0
Release:        bp154.1.19
Summary:        Vicious plugins for awesome
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/vicious-widgets/vicious
Source:         %{url}/archive/v%{version}.tar.gz#/%{packname}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       awesome >= 3.4.4
Recommends:     awesome-freedesktop
Recommends:     awesome-shifty
BuildArch:      noarch

%description
Vicious is a modular widget library for the "awesome" window manager,
derived from the "Wicked" widget library. It has some of the old
Wicked widget types, a few of them rewritten, and a good number of new
ones.

Vicious widget types are a framework for creating your own awesome
widgets. Vicious contains modules that gather data about your system,
and a few helper functions that make it easier to register timers,
suspend widgets and so on.

For now Vicious doesn't depend on any third party Lua libraries, to
make it easier to install and use. That means some system utilities
are used instead, where available:

  - hddtemp        for the HDD Temperature widget type
  - alsa-utils     for the Volume widget type
  - wireless_tools for the Wireless widget type
  - curl           for widget types accessing network resources

%prep
%autosetup -n %{packname}-%{version}

%build

%install
install -d %{buildroot}/%{_datadir}/awesome/lib/vicious/contrib
install -d %{buildroot}/%{_datadir}/awesome/lib/vicious/widgets
install -Dm 644 contrib/* %{buildroot}/%{_datadir}/awesome/lib/vicious/contrib
install -Dm 644 widgets/* %{buildroot}/%{_datadir}/awesome/lib/vicious/widgets
install -Dm 644 init.lua  %{buildroot}/%{_datadir}/awesome/lib/vicious
install -Dm 644 helpers.lua  %{buildroot}/%{_datadir}/awesome/lib/vicious
install -Dm 644 spawn.lua  %{buildroot}/%{_datadir}/awesome/lib/vicious

%files
%doc README.md CHANGELOG.rst TODO
%license LICENSE
%dir %{_datadir}/awesome
%dir %{_datadir}/awesome/lib
%{_datadir}/awesome/lib/vicious

%changelog
* Thu May 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update old RPM macros/constructs.
* Wed May 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.5.0
  * Added vicious.call_async asynchronous analogous to vicious.call
  * Feature: [hwmontemp] Bring back sysfs path cache
  * Fixed fallback the number of lines before packages listing to 0
  * Remove trailing semicolon at the end of command.
  * volume now uses other emojis to show mute state.
    This BREAKS backward compatibility if users substitute custom
    symbols from these default.
  * Added notmuch_all, cpu_freebsd widget types
  * [cmus_all] Promote to widgets/.
  * [wifiiw_linux] Expose BSSID.
  * [wifi_linux] Expose frequency and transmission power.
  * spawn as a fallback for awful.spawn in case Vicious is used as a
    stand-alone library.
  * Added helpers.setasyncall to avoid writing redundant workers for
    asynchronous widget types.
  * Added helpers.setcall for registering functions as widget types.
  * Deprecate the use of io.popen
  * [pkg,weather,contrib/btc] Allow function call without Awesome
  * Removed: helpers.sysctl and helpers.sysctl_table were removed
    in favour of helpers.sysctl_async.
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.3.3
  * LUA 5.3 compatibility
  * Support stacked graphs
  * hwmontemp_linux: Provide name-based access to hwmon sensors
    via sysfs
  * mpd_all: Expose more informations and format time in [hh:]mm:ss
  * Improve defaults and mechanism for data caching
  * Escape XML entities in results by default
  * weather_all: Update NOAA link and use Awesome asynchronous API
  * mem_linux: Use MemAvailable to calculate free amount
  * mem_freebsd: Correct calculation and switch to swapinfo for swap
  * bat_freebsd: Add critical charging state
  * fs_all: Fix shell quoting of option arguments
* Mon Jun 18 2018 okurz@suse.com
- Update to version 2.3.1:
  * Allow widget to be a function again
  * btc: also usuable with cjson
  * btc: remove synchronous variant and dead code
  * Bitcoin price widget.
  * Do not hide loading errors when widgets failed to load
  * cmus: use correct shell escape function
  * Add widget for cmus (follow mpd conventions) (#46)
- Switch to https://github.com/Mic92/vicious
* Fri Dec 19 2014 p.drouand@gmail.com
- Update to version 2.1.3
  + bat: fix broken battery remaining time (was always N/A)
  + volume: get the normalized volume like alsamixer and DE's indicator
- Use download Url as source
* Thu Nov  8 2012 toganm@opensuse.org
- Change license to GPL-2.0+
* Wed Oct 31 2012 toganm@opensuse.org
- Update to official version 2.1.0
  Cleanup spec to meet guidelines
* Sat Feb 11 2012 toganm@opensuse.org
- Update to git201202051838
  * hddtemp: fix curl hang in version 7.24.0
* Wed Jan 25 2012 toganm@opensuse.org
- Update to git201201201335
  * Created AUTHORS and removed the names from spec
* Wed Dec 21 2011 toganm@opensuse.org
- fixed spec
- removed service file
* Tue Dec 20 2011 toganm@opensuse.org
- Switch to git version via service files
